#include "mainwidget.h"
#include "ui_mainwidget.h"

MainWidget::MainWidget(QWidget *parent, QString name) :
    QWidget(parent),
    ui(new Ui::MainWidget)
{
    ui->setupUi(this);
    //Сохранение имени виджета в свойстве ObjectName
    setObjectName(name);
    //Отображение имени виджет в заголовке окна виджета
    setWindowTitle(name);

    //Связывание сигнала со слотом "сохранение настроек"
    connect(this, SIGNAL(beforeDestroy()), SLOT(saveGeometry()));

    //Создание объекта для работы с настройками
    settings = new QSettings(this);
    //Загрузка геометрии из настройки
    loadGeometry();
}

MainWidget::~MainWidget()
{
    //Испускание сигнала beforeDestroy
    emit beforeDestroy();

    delete ui;
}

void MainWidget::loadGeometry()
{
    //Открытие группы "forms"
    settings->beginGroup("forms");
    //Открытие группы с "имя виджета"
    settings->beginGroup(this->objectName());
    //Получение и применение настройки
    setGeometry(settings->value("geometry", QRect(100, 100, 300, 300)).toRect());
    //Закрытие группы с "имя виджета"
    settings->endGroup();
    //Закрытие группы "forms"
    settings->endGroup();

}

void MainWidget::saveGeometry()
{
    //Открытие группы "forms"
    settings->beginGroup("forms");
    //Открытие группы с "имя виджета"
    settings->beginGroup(this->objectName());
    //Сохранение настройки
    settings->setValue("geometry", geometry());
    //Закрытие группы с "имя виджета"
    settings->endGroup();
    //Закрытие группы "forms"
    settings->endGroup();
}
